==> dcl-c_5.3.3.orig.tar.gz: dcl-c-5.3.3/src/misc1/bitlib/bitpic.c <==
/*  -- translated by f2c (version 20050501).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__1 = 1;

/* ----------------------------------------------------------------------- */
/*     BITPIC */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int bitpic_(integer *ip, char *cp, ftnlen cp_len)
{
    /* Initialized data */

    static logical lfst = TRUE_;

    /* System generated locals */
    integer i__1;

    /* Builtin functions */
    integer i_len(char *, ftnlen);

    /* Local variables */
    static integer i__, ii, nbc, mask[32];
    extern /* Subroutine */ int gliget_(char *, integer *, ftnlen);
    extern integer ishift_(integer *, integer *);
    extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
	    ftnlen, ftnlen);
    static integer nbitpw;

    if (lfst) {
	gliget_("NBITSPW", &nbitpw, (ftnlen)7);
	if (nbitpw != 32) {
	    msgdmp_("E", "BITPIC", "NUMBER OF BITS PER ONE WORD IS INVALID /"
		    " CHECK NB IN THE PARAMETER STATEMENT OF BITPIC AND CHANG"
		    "E IT CORRECTLY.", (ftnlen)1, (ftnlen)6, (ftnlen)111);
	}
	mask[0] = 1;
	for (i__ = 2; i__ <= 32; ++i__) {
	    mask[i__ - 1] = ishift_(&mask[i__ - 2], &c__1);
/* L10: */
	}
	lfst = FALSE_;
    }
    nbc = i_len(cp, cp_len);
    i__1 = min(nbc,32);
    for (i__ = 1; i__ <= i__1; ++i__) {
	ii = nbc - i__ + 1;
	if ((mask[i__ - 1] & *ip) == 0) {
	    *(unsigned char *)&cp[ii - 1] = '0';
	} else {
	    *(unsigned char *)&cp[ii - 1] = '1';
	}
/* L15: */
    }
    return 0;
} /* bitpic_ */

==> dcl-c_5.3-20050523-1.tar.gz: dcl-c-5.3-20050523/src/misc1/bitlib/bitpic.c <==
/* src/misc1/bitlib/bitpic.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__1 = 1;

/* ----------------------------------------------------------------------- */
/*     BITPIC */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int bitpic_(integer *ip, char *cp, ftnlen cp_len)
{
    /* Initialized data */

    static logical lfst = TRUE_;

    /* System generated locals */
    integer i__1;

    /* Builtin functions */
    integer i_len(char *, ftnlen);

    /* Local variables */
    static integer i__, ii, nbc, mask[32];
    extern /* Subroutine */ int gliget_(char *, integer *, ftnlen);
    extern integer ishift_(integer *, integer *);
    extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
	    ftnlen, ftnlen);
    static integer nbitpw;

    if (lfst) {
	gliget_("NBITSPW", &nbitpw, (ftnlen)7);
	if (nbitpw != 32) {
	    msgdmp_("E", "BITPIC", "NUMBER OF BITS PER ONE WORD IS INVALID /"
		    " CHECK NB IN THE PARAMETER STATEMENT OF BITPIC AND CHANG"
		    "E IT CORRECTLY.", (ftnlen)1, (ftnlen)6, (ftnlen)111);
	}
	mask[0] = 1;
	for (i__ = 2; i__ <= 32; ++i__) {
	    mask[i__ - 1] = ishift_(&mask[i__ - 2], &c__1);
/* L10: */
	}
	lfst = FALSE_;
    }
    nbc = i_len(cp, cp_len);
    i__1 = min(nbc,32);
    for (i__ = 1; i__ <= i__1; ++i__) {
	ii = nbc - i__ + 1;
	if ((mask[i__ - 1] & *ip) == 0) {
	    *(unsigned char *)&cp[ii - 1] = '0';
	} else {
	    *(unsigned char *)&cp[ii - 1] = '1';
	}
/* L15: */
    }
    return 0;
} /* bitpic_ */
